#include <glib.h>
#include "found-gtk-widget.h"

static const gchar *
get_attention_style_class_name (GtkWidgetAttentionStyle style)
{
    const gchar *class_name = NULL;
    switch (style)
    {
        case GTK_WIDGET_ATTENTION_SUGGESTED:
            class_name = GTK_STYLE_CLASS_SUGGESTED_ACTION;
            break;
        case GTK_WIDGET_ATTENTION_DESTRUCTIVE:
            class_name = GTK_STYLE_CLASS_DESTRUCTIVE_ACTION;
            break;
        case GTK_WIDGET_ATTENTION_IMPORTANT:
            class_name = GTK_STYLE_CLASS_NEEDS_ATTENTION;
            break;
        case GTK_WIDGET_ATTENTION_WARNING:
            class_name = GTK_STYLE_CLASS_WARNING;
            break;
        case GTK_WIDGET_ATTENTION_ERROR:
            class_name = GTK_STYLE_CLASS_ERROR;
            break;
        case GTK_WIDGET_ATTENTION_SUCCESS:
            class_name = "success";
            break; 
        default:
            break;
    }
    return class_name;
}

void
gtk_widget_set_attention_style (GtkWidget *widget, 
                                GtkWidgetAttentionStyle style)
{
    g_return_if_fail (GTK_IS_WIDGET (widget));
    GtkStyleContext *context;
    const gchar *class_name = NULL;
    const gchar *att;
    GtkWidgetAttentionStyle st;

    context = gtk_widget_get_style_context (widget);
    st = GPOINTER_TO_INT (g_object_get_data (widget, "attention-style"));
    if (st == style)
        return;

    class_name = get_attention_style_class_name (style);
    att = g_object_get_data (widget, "attention-class");
    if (att && gtk_style_context_has_class (context, att))
    {
        gtk_style_context_remove_class (context, att);
    }
    if (style != GTK_WIDGET_ATTENTION_NONE)
    {
        gtk_style_context_add_class (context, class_name);
    }
    g_object_set_data (widget, "attention-class", class_name);
    g_object_set_data (widget, "attention-style", GINT_TO_POINTER (style));
}

GtkWidgetAttentionStyle
gtk_widget_get_attention_style (GtkWidget *widget)
{
    g_return_val_if_fail (GTK_IS_WIDGET (widget), GTK_WIDGET_ATTENTION_NONE);
    GtkWidgetAttentionStyle st;
    st = GPOINTER_TO_INT (g_object_get_data (widget, "attention-style"));

    return st;
}

void
gtk_widget_style_context_replace_class (GtkWidget *widget, 
                                        const gchar *origin_class, 
                                        const gchar *new_class)
{
    g_return_if_fail (GTK_IS_WIDGET (widget));
    GtkStyleContext *context;
    context = gtk_widget_get_style_context (widget);
    if (gtk_style_context_has_class (context, origin_class))
    {
        gtk_style_context_remove_class (context, origin_class);
    }
    gtk_style_context_add_class (context, new_class);
}
